@@ -11,7 +11,7 @@ from jsii.python import classproperty
 
 import aws_cdk.aws_cloudwatch
 import aws_cdk.aws_iam
-import aws_cdk.cdk
+import aws_cdk.core
 __all__ = []
 
 publication.publish()
